# parse\_fcc\_uls

Tool for Downloading and Parsing FCC ULS database.

### Syntax:
```console
bash create_db.bash
```

This will download the amature radio and GMRS radio license data from the FCC's weekly database releases, and load it into an sqlite3 database. 
